==> bluesmet-0.4.0.dev0.tar.gz: bluesmet-0.4.0.dev0/src/bluesmet/normet/nora3/wave_sub_time.py <==
from datetime import datetime
from typing import Sequence

from dateutil import rrule

from bluesmet.normet.dataset import Dataset

from ..combine import get_values_between as get_values


def get_values_between(
    lat_pos: float,
    lon_pos: float,
    start_date: datetime,
    end_date: datetime,
    requested_values: Sequence[str],
    cache_location="./cache/wave_sub_time/",
    max_concurrent_downloads = 1
):
    """Return values for wave_sub_time dataset"""

    return get_values(
        requested_values,
        lat_pos,
        lon_pos,
        "longitude",
        "latitude",
        start_date,
        end_date,
        rrule.MONTHLY,
        cache_location,
        __get_url,
        max_concurrent_downloads
    )


def __get_url(date: datetime):
    basename = "NORA3wave_sub_time_unlimited"
    base_url = "https://thredds.met.no/thredds/dodsC/nora3wavesubset_files/wave_v4/"
    dataset_name = f"_{basename}"
    datlab = date.strftime("%Y%m")
    return base_url + datlab + dataset_name + ".nc"


def get_metadata():
    """Get metadata"""
    from_date = datetime(1989, 1, 1)
    to_date = datetime(2022, 12, 31)
    url = __get_url(from_date)
    ds = Dataset("./cache/wave_sub_time/", url, from_date)
    metadata = ds.get_metadata()
    metadata["global"] = {
        "fromDate": from_date.strftime("%Y-%m-%dT%H:%M:%SZ"),
        "toDate": to_date.strftime("%Y-%m-%dT%H:%M:%SZ"),
        "url": "https://thredds.met.no/thredds/catalog/nora3wavesubset_files/wave_v4/catalog.html",
    }
    return metadata

==> bluesmet-0.4.4.tar.gz: bluesmet-0.4.4/src/bluesmet/normet/nora3/wave_sub_time.py <==
from datetime import datetime
from typing import Sequence

from dateutil import rrule

from bluesmet.normet.dataset import Dataset

from ..combine import get_values_between as get_values


def get_values_between(
    lat_pos: float,
    lon_pos: float,
    start_date: datetime,
    end_date: datetime,
    requested_values: Sequence[str],
    cache_location="./cache/wave_sub_time/",
    max_concurrent_downloads = 1
):
    """Return values for wave_sub_time dataset"""

    return get_values(
        requested_values,
        lat_pos,
        lon_pos,
        "longitude",
        "latitude",
        start_date,
        end_date,
        rrule.MONTHLY,
        cache_location,
        __get_url,
        max_concurrent_downloads
    )


def __get_url(date: datetime):
    basename = "NORA3wave_sub_time_unlimited"
    base_url = "https://thredds.met.no/thredds/dodsC/nora3_subset_wave/wave_tser/"
    dataset_name = f"_{basename}"
    datlab = date.strftime("%Y%m")
    return base_url + datlab + dataset_name + ".nc"


def get_metadata():
    """Get metadata"""
    from_date = datetime(1989, 1, 1)
    to_date = datetime(2022, 12, 31)
    url = __get_url(from_date)
    ds = Dataset("./cache/wave_sub_time/", url, from_date)
    metadata = ds.get_metadata()
    metadata["global"] = {
        "fromDate": from_date.strftime("%Y-%m-%dT%H:%M:%SZ"),
        "toDate": to_date.strftime("%Y-%m-%dT%H:%M:%SZ"),
        "url": "https://thredds.met.no/thredds/catalog/nora3_subset_wave/wave_tser/catalog.html",
    }
    return metadata
